#[non_exhaustive]pub struct Declaration {
pub name: String,
pub kind: DeclarationKind,
pub span: Span,
pub extent: Span,
pub owner: Option<String>,
pub exported: bool,
}Expand description
A named declaration and where it was written.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Stringkind: DeclarationKindspan: SpanExact source occupied by the declaration name and its modifiers.
extent: SpanFull source occupied by the declaration, including its body when one exists.
owner: Option<String>Enclosing declaration, when the language nests them.
exported: boolWhether the declaration leaves the module.