Language

Enum Language 

#[non_exhaustive]
pub enum Language {
Show 25 variants JavaScript, TypeScript, Graphql, Protobuf, Rust, Python, Go, Java, CSharp, C, Cpp, Sql, Solidity, Swift, Terraform, Html, Xml, Markdown, Mdx, ReStructuredText, AsciiDoc, Css, Scss, Bash, Yaml,
}
A language this crate can tokenize.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


JavaScript



TypeScript



Graphql



Protobuf



Rust



Python



Go



Java



CSharp



C



Cpp



Sql



Solidity



Swift



Terraform



Html



Xml



Markdown



Mdx

Markdown with JavaScript imports and components.



ReStructuredText



AsciiDoc



Css



Scss

SCSS, Sass and Less, which differ from CSS by allowing // comments and nesting selectors.



Bash



Yaml

Implementations

Source

impl Language

pub fn from_extension(extension: &str) -> Option<Self>

The language a file extension selects, if this crate handles it.

pub const fn as_str(self) -> &'static str

Source

impl Language

pub const fn syntax(self) -> Syntax

The lexical rules this language follows.