pub struct Token {
pub kind: TokenKind,
pub start: usize,
pub end: usize,
pub line: u32,
pub column: u32,
}Expand description
One lexical unit and its exact position in the source.
Fields
kind: TokenKindstart: usizeByte range in the source; source[start..end] is the token text.
end: usizeline: u32One-based line of the first byte.
column: u32One-based column, counted in characters, of the first byte.
Implementations